#
# spec file for package terraform-provider-external
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global provider        github
%global provider_tld    com
%global project         terraform-providers
%global repo            terraform-provider-external
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    external

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-external
Version:        2.0.0
Release:        6.3.1
Summary:        Terraform External provider
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/%{name}
Source:         %{repo}-%{version}.tar.xz
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
Requires:       terraform >= 0.12.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang(API) >= 1.12
BuildRequires:  golang-packaging
BuildRequires:  xz
%endif
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
Tarraform provider for external data

%prep
%setup -q

%build
%{goprep} %{import_path}
%{gobuild} -mod=vendor ""

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Wed Nov 11 2020 adrian.glaubitz@suse.com
- Add symbolic link to comply with new filesystem layout for local provider copies
* Mon Oct 19 2020 adrian.glaubitz@suse.com
- Update to version 2.0.0:
  * Update CHANGELOG.md
  * add .tfproto5 file for releases
  * Update CHANGELOG.md
  * Add descriptions
  * update CI and Go version
  * follow scaffolding conventions
  * SDK v2.0.3
  * migrate to standalone plugin SDK
  * let's print this as a string
  * restore hashibot behaviors after org transfer
  * enable go modules and vendoring in travis
  * Update CHANGELOG.md
  * switch to standalone tf plugin sdk
  * vendor: Bump terraform to 0.12.8
  * Cleanup after v1.2.0 release
- Define and use common Go spec file variables
* Sat Feb  8 2020 rjschwei@suse.com
- Initial Build:
  * v1.2.0
  * Update CHANGELOG.md
  * Add a trace logging for the JSON output
  * Cleanup after v1.1.2 release
  * v1.1.2
  * Update CHANGELOG.md
  * Upgrade terraform sdk to v0.12-early9
  * Cleanup after v1.1.1 release
  * v1.1.1
  * Update CHANGELOG.md
